namespace Sidra.IntegrationHub.Client.Sample.Common
{
    public static class Constants
    {
        internal static class Common
        {
            /// <summary>
            /// Name of the existing Topic where to publish or receive the message
            /// </summary>
            public const string TopicName = "topic_name_here";

            /// <summary>
            /// Identity provider (Identity Server in this case) token endpoint where to request the user's token
            /// </summary>
            public const string TokenProviderEndpoint = "https://foo-authentication-capp.foo.region.azurecontainerapps.io/connect/token";

            /// <summary>
            /// Identity provider's client identifier. (Client which scope it's to request the Sidra Web)
            /// </summary>
            public const string ClientId = "client_here";

            /// <summary>
            /// Identity provider client's password credential
            /// </summary>
            public const string Secret = "secret_here";

            /// <summary>
            /// Identity provider's client's scope
            /// </summary>
            public const string Scope = "sidra.api";

            /// <summary>
            /// URI of Sidra's Core API
            /// </summary>
            public const string IntegrationHubApiEndpoint = "https://foo-core-bar-api-capp.foo.region.azurecontainerapps.io";

            /// <summary>
            /// Identifier to the DSU
            /// </summary>
            public const int DefaultDsu = 1;
        }

        public static class Publisher
        {
            /// <summary>
            /// Name of the existing Topic where to publish or receive the message
            /// </summary>
            public const string TopicName = Common.TopicName;

            /// <summary>
            /// Name of the existing policy name (Must have 'Send' policy at least, to be able to publish the message)
            /// </summary>
            public const string PolicyName = "policy_name_here";

            /// <summary>
            /// Identity provider (Identity Server in this case) token endpoint where to request the user's token
            /// </summary>
            public const string TokenProviderEndpoint = Common.TokenProviderEndpoint;

            /// <summary>
            /// Identity provider's client identifier. (Client which scope it's to request the Sidra Web)
            /// </summary>
            public const string ClientId = Common.ClientId;

            /// <summary>
            /// Identity provider client's password credential
            /// </summary>
            public const string Secret = Common.Secret;

            /// <summary>
            /// Identity provider's client's scope
            /// </summary>
            public const string Scope = Common.Scope;

            /// <summary>
            /// URI of Sidra's Core API
            /// </summary>
            public const string IntegrationHubApiEndpoint = Common.IntegrationHubApiEndpoint;

            /// <summary>
            /// Identifier to the DSU
            /// </summary>
            public const int DefaultDsu = Common.DefaultDsu;
        }

        public static class Consumer
        {
            /// <summary>
            /// Name of the existing Topic where to publish or receive the message
            /// </summary>
            public const string TopicName = Common.TopicName;

            /// <summary>
            /// Name of the existing policy name (Must have 'Send' policy at least, to be able to publish the message)
            /// </summary>
            public const string PolicyName = "policy_name_here";

            /// <summary>
            /// Identity provider (Identity Server in this case) token endpoint where to request the user's token
            /// </summary>
            public const string TokenProviderEndpoint = Common.TokenProviderEndpoint;

            /// <summary>
            /// Identity provider's client identifier. (Client which scope it's to request the Sidra Web)
            /// </summary>
            public const string ClientId = Common.ClientId;

            /// <summary>
            /// Identity provider client's password credential
            /// </summary>
            public const string Secret = Common.Secret;

            /// <summary>
            /// Identity provider's client's scope
            /// </summary>
            public const string Scope = Common.Scope;

            /// <summary>
            /// URI of Sidra's Core API
            /// </summary>
            public const string IntegrationHubApiEndpoint = Common.IntegrationHubApiEndpoint;

            /// <summary>
            /// Name of the existing Topic's subscription to listen the messages
            /// </summary>
            public const string SubscriptionOne = "subscription_name_here";

            /// <summary>
            /// Identifier to the DSU
            /// </summary>
            public const int DefaultDsu = Common.DefaultDsu;
        }
    }
}