using Microsoft.Extensions.DependencyInjection;
using Sidra.IntegrationHub.Client.Contracts.Managers;
using Sidra.IntegrationHub.Client.IoCC;
using Sidra.IntegrationHub.Client.IoCC.Options;
using Sidra.IntegrationHub.Client.Sample.Common;
using Sidra.IntegrationHub.Client.Sample.EventConsumer;
using System.Reflection;

class Program
{
    static async Task Main(string[] args)
    {
        await Console.Out.WriteLineAsync("Starting event consumer..");

        var serviceProviderConsumerOne =
            new ServiceCollection()
                .RegisterEventConsumer(
                    sp =>
                    {
                        var serviceBusOptions =
                            new IntegrationHubConsumerOptions
                            {
                                TopicName = Constants.Consumer.TopicName,
                                PolicyName = Constants.Consumer.PolicyName,
                                SubscriptionName = Constants.Consumer.SubscriptionOne,
                                TokenProviderUri = new Uri(Constants.Consumer.TokenProviderEndpoint),
                                ClientId = Constants.Consumer.ClientId,
                                ClientSecret = Constants.Consumer.Secret,
                                Scope = Constants.Consumer.Scope,
                                IntegrationHubApiEndpoint = new Uri(Constants.Consumer.IntegrationHubApiEndpoint),
                                IdDataStorageUnit = Constants.Consumer.DefaultDsu
                            };
                        return serviceBusOptions;
                    },
                    typeof(EventOneHandler).GetTypeInfo().Assembly)
                .BuildServiceProvider();

        await Console.Out.WriteLineAsync("Starting consumer one..");
        var eventConsumerOneManager = serviceProviderConsumerOne.GetService<IEventConsumerBusManager>();
        await eventConsumerOneManager.Start();

        await Console.Out.WriteLineAsync("Press enter to end consumers.");
        await Console.In.ReadLineAsync();
        await eventConsumerOneManager.Stop();
    }
}